Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(784)

Unified Diff: third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h

Issue 1888703002: Worker: Rename worker components to clarify what they work for (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: add missing files Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h
diff --git a/third_party/WebKit/Source/core/workers/WorkerMessagingProxy.h b/third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h
similarity index 87%
rename from third_party/WebKit/Source/core/workers/WorkerMessagingProxy.h
rename to third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h
index 1810ccd81a6e6216775931397a672bdad5c50cc6..7498ce5a5b930f5ed655f37bb8ffd494d11ccfb0 100644
--- a/third_party/WebKit/Source/core/workers/WorkerMessagingProxy.h
+++ b/third_party/WebKit/Source/core/workers/InProcessWorkerMessagingProxy.h
@@ -24,12 +24,12 @@
*
*/
-#ifndef WorkerMessagingProxy_h
-#define WorkerMessagingProxy_h
+#ifndef InProcessWorkerMessagingProxy_h
+#define InProcessWorkerMessagingProxy_h
#include "core/CoreExport.h"
#include "core/dom/ExecutionContext.h"
-#include "core/workers/WorkerGlobalScopeProxy.h"
+#include "core/workers/InProcessWorkerGlobalScopeProxy.h"
#include "core/workers/WorkerLoaderProxy.h"
#include "wtf/Forward.h"
#include "wtf/Noncopyable.h"
@@ -47,12 +47,15 @@ class InProcessWorkerBase;
class WorkerClients;
class WorkerInspectorProxy;
-class CORE_EXPORT WorkerMessagingProxy
- : public WorkerGlobalScopeProxy
+// TODO(nhiroki): "MessagingProxy" is not well-defined term among worker
+// components. Probably we should rename this to something more suitable.
+// (http://crbug.com/603785)
+class CORE_EXPORT InProcessWorkerMessagingProxy
+ : public InProcessWorkerGlobalScopeProxy
, private WorkerLoaderProxyProvider {
- WTF_MAKE_NONCOPYABLE(WorkerMessagingProxy);
+ WTF_MAKE_NONCOPYABLE(InProcessWorkerMessagingProxy);
public:
// Implementations of WorkerGlobalScopeProxy.
// (Only use these methods in the worker object thread.)
void startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode) override;
void terminateWorkerGlobalScope() override;
@@ -76,8 +79,8 @@ public:
ExecutionContext* getExecutionContext() const { return m_executionContext.get(); }
protected:
- WorkerMessagingProxy(InProcessWorkerBase*, WorkerClients*);
- ~WorkerMessagingProxy() override;
+ InProcessWorkerMessagingProxy(InProcessWorkerBase*, WorkerClients*);
+ ~InProcessWorkerMessagingProxy() override;
virtual PassOwnPtr<WorkerThread> createWorkerThread(double originTime) = 0;
@@ -115,4 +118,4 @@ private:
} // namespace blink
-#endif // WorkerMessagingProxy_h
+#endif // InProcessWorkerMessagingProxy_h

Powered by Google App Engine
This is Rietveld 408576698
@@ -47,12 +47,15 @@ class InProcessWorkerBase;
public:
- // Implementations of WorkerGlobalScopeProxy.
+ // Implementations of InProcessWorkerGlobalScopeProxy.
// (Only use these methods in the worker object thread.)
void startWorkerGlobalScope(const KURL& scriptURL, const String& userAgent, const String& sourceCode) override;